@@ -87,9 +87,8 @@ PULP_STATUS_MAPPING = {
 }
 
 
-class InvalidUsage(Exception):
+class AirflowError(Exception):
     status_code = 400
-    error = "Unknown error"
 
     def __init__(self, error=None, status_code=None, payload=None):
         Exception.__init__(self)
@@ -105,16 +104,6 @@ class InvalidUsage(Exception):
         return rv
 
 
-class AirflowError(InvalidUsage):
-    status_code = 400
-
-    def __init__(self, error, status_code=None, payload=None):
-        self.error = error
-        self.payload = payload
-        if status_code is not None:
-            self.status_code = status_code
-
-
 class NoSolverException(Exception):
     pass
 
